@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "clojure-mode" "5.22.0"
+(define-package "clojure-mode" "20250527.840"
   "Major mode for Clojure code."
-  '((emacs "27.1"))
+  '((emacs "25.1"))
   :url "https://github.com/clojure-emacs/clojure-mode"
-  :commit "6314697ed8042db9341a11d1a330c305a3c36f37"
-  :revdesc "6314697ed804"
+  :commit "d336db623e7ae8cffff50aaaea3f1b05cc4ccecb"
+  :revdesc "d336db623e7a"
   :keywords '("languages" "clojure" "clojurescript" "lisp")
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
